--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Khmer_Symbols is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Khmer_Symbol_Pathamasat                 : constant Unicode_Char := 16#19E0#;
   Khmer_Symbol_Muoy_Koet                  : constant Unicode_Char := 16#19E1#;
   Khmer_Symbol_Pii_Koet                   : constant Unicode_Char := 16#19E2#;
   Khmer_Symbol_Bei_Koet                   : constant Unicode_Char := 16#19E3#;
   Khmer_Symbol_Buon_Koet                  : constant Unicode_Char := 16#19E4#;
   Khmer_Symbol_Pram_Koet                  : constant Unicode_Char := 16#19E5#;
   Khmer_Symbol_Pram_Muoy_Koet             : constant Unicode_Char := 16#19E6#;
   Khmer_Symbol_Pram_Pii_Koet              : constant Unicode_Char := 16#19E7#;
   Khmer_Symbol_Pram_Bei_Koet              : constant Unicode_Char := 16#19E8#;
   Khmer_Symbol_Pram_Buon_Koet             : constant Unicode_Char := 16#19E9#;
   Khmer_Symbol_Dap_Koet                   : constant Unicode_Char := 16#19EA#;
   Khmer_Symbol_Dap_Muoy_Koet              : constant Unicode_Char := 16#19EB#;
   Khmer_Symbol_Dap_Pii_Koet               : constant Unicode_Char := 16#19EC#;
   Khmer_Symbol_Dap_Bei_Koet               : constant Unicode_Char := 16#19ED#;
   Khmer_Symbol_Dap_Buon_Koet              : constant Unicode_Char := 16#19EE#;
   Khmer_Symbol_Dap_Pram_Koet              : constant Unicode_Char := 16#19EF#;
   Khmer_Symbol_Tuteyasat                  : constant Unicode_Char := 16#19F0#;
   Khmer_Symbol_Muoy_Roc                   : constant Unicode_Char := 16#19F1#;
   Khmer_Symbol_Pii_Roc                    : constant Unicode_Char := 16#19F2#;
   Khmer_Symbol_Bei_Roc                    : constant Unicode_Char := 16#19F3#;
   Khmer_Symbol_Buon_Roc                   : constant Unicode_Char := 16#19F4#;
   Khmer_Symbol_Pram_Roc                   : constant Unicode_Char := 16#19F5#;
   Khmer_Symbol_Pram_Muoy_Roc              : constant Unicode_Char := 16#19F6#;
   Khmer_Symbol_Pram_Pii_Roc               : constant Unicode_Char := 16#19F7#;
   Khmer_Symbol_Pram_Bei_Roc               : constant Unicode_Char := 16#19F8#;
   Khmer_Symbol_Pram_Buon_Roc              : constant Unicode_Char := 16#19F9#;
   Khmer_Symbol_Dap_Roc                    : constant Unicode_Char := 16#19FA#;
   Khmer_Symbol_Dap_Muoy_Roc               : constant Unicode_Char := 16#19FB#;
   Khmer_Symbol_Dap_Pii_Roc                : constant Unicode_Char := 16#19FC#;
   Khmer_Symbol_Dap_Bei_Roc                : constant Unicode_Char := 16#19FD#;
   Khmer_Symbol_Dap_Buon_Roc               : constant Unicode_Char := 16#19FE#;
   Khmer_Symbol_Dap_Pram_Roc               : constant Unicode_Char := 16#19FF#;
end Unicode.Names.Khmer_Symbols;
