--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Devanagari_Extended is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Combining_Devanagari_Digit_Zero         : constant Unicode_Char := 16#A8E0#;
   Combining_Devanagari_Digit_One          : constant Unicode_Char := 16#A8E1#;
   Combining_Devanagari_Digit_Two          : constant Unicode_Char := 16#A8E2#;
   Combining_Devanagari_Digit_Three        : constant Unicode_Char := 16#A8E3#;
   Combining_Devanagari_Digit_Four         : constant Unicode_Char := 16#A8E4#;
   Combining_Devanagari_Digit_Five         : constant Unicode_Char := 16#A8E5#;
   Combining_Devanagari_Digit_Six          : constant Unicode_Char := 16#A8E6#;
   Combining_Devanagari_Digit_Seven        : constant Unicode_Char := 16#A8E7#;
   Combining_Devanagari_Digit_Eight        : constant Unicode_Char := 16#A8E8#;
   Combining_Devanagari_Digit_Nine         : constant Unicode_Char := 16#A8E9#;
   Combining_Devanagari_Letter_A           : constant Unicode_Char := 16#A8EA#;
   Combining_Devanagari_Letter_U           : constant Unicode_Char := 16#A8EB#;
   Combining_Devanagari_Letter_Ka          : constant Unicode_Char := 16#A8EC#;
   Combining_Devanagari_Letter_Na          : constant Unicode_Char := 16#A8ED#;
   Combining_Devanagari_Letter_Pa          : constant Unicode_Char := 16#A8EE#;
   Combining_Devanagari_Letter_Ra          : constant Unicode_Char := 16#A8EF#;
   Combining_Devanagari_Letter_Vi          : constant Unicode_Char := 16#A8F0#;
   Combining_Devanagari_Sign_Avagraha      : constant Unicode_Char := 16#A8F1#;
   Devanagari_Sign_Spacing_Candrabindu     : constant Unicode_Char := 16#A8F2#;
   Devanagari_Sign_Candrabindu_Virama      : constant Unicode_Char := 16#A8F3#;
   Devanagari_Sign_Double_Candrabindu_Virama :
      constant Unicode_Char := 16#A8F4#;
   Devanagari_Sign_Candrabindu_Two         : constant Unicode_Char := 16#A8F5#;
   Devanagari_Sign_Candrabindu_Three       : constant Unicode_Char := 16#A8F6#;
   Devanagari_Sign_Candrabindu_Avagraha    : constant Unicode_Char := 16#A8F7#;
   Devanagari_Sign_Pushpika                : constant Unicode_Char := 16#A8F8#;
   Devanagari_Gap_Filler                   : constant Unicode_Char := 16#A8F9#;
   Devanagari_Caret                        : constant Unicode_Char := 16#A8FA#;
   Devanagari_Headstroke                   : constant Unicode_Char := 16#A8FB#;
   Devanagari_Sign_Siddham                 : constant Unicode_Char := 16#A8FC#;
   Devanagari_Jain_Om                      : constant Unicode_Char := 16#A8FD#;
end Unicode.Names.Devanagari_Extended;
