--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Ethiopic_Extended_A is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Ethiopic_Syllable_Tthu                  : constant Unicode_Char := 16#AB01#;
   Ethiopic_Syllable_Tthi                  : constant Unicode_Char := 16#AB02#;
   Ethiopic_Syllable_Tthaa                 : constant Unicode_Char := 16#AB03#;
   Ethiopic_Syllable_Tthee                 : constant Unicode_Char := 16#AB04#;
   Ethiopic_Syllable_Tthe                  : constant Unicode_Char := 16#AB05#;
   Ethiopic_Syllable_Ttho                  : constant Unicode_Char := 16#AB06#;
   Ethiopic_Syllable_Ddhu                  : constant Unicode_Char := 16#AB09#;
   Ethiopic_Syllable_Ddhi                  : constant Unicode_Char := 16#AB0A#;
   Ethiopic_Syllable_Ddhaa                 : constant Unicode_Char := 16#AB0B#;
   Ethiopic_Syllable_Ddhee                 : constant Unicode_Char := 16#AB0C#;
   Ethiopic_Syllable_Ddhe                  : constant Unicode_Char := 16#AB0D#;
   Ethiopic_Syllable_Ddho                  : constant Unicode_Char := 16#AB0E#;
   Ethiopic_Syllable_Dzu                   : constant Unicode_Char := 16#AB11#;
   Ethiopic_Syllable_Dzi                   : constant Unicode_Char := 16#AB12#;
   Ethiopic_Syllable_Dzaa                  : constant Unicode_Char := 16#AB13#;
   Ethiopic_Syllable_Dzee                  : constant Unicode_Char := 16#AB14#;
   Ethiopic_Syllable_Dze                   : constant Unicode_Char := 16#AB15#;
   Ethiopic_Syllable_Dzo                   : constant Unicode_Char := 16#AB16#;
   Ethiopic_Syllable_Cchha                 : constant Unicode_Char := 16#AB20#;
   Ethiopic_Syllable_Cchhu                 : constant Unicode_Char := 16#AB21#;
   Ethiopic_Syllable_Cchhi                 : constant Unicode_Char := 16#AB22#;
   Ethiopic_Syllable_Cchhaa                : constant Unicode_Char := 16#AB23#;
   Ethiopic_Syllable_Cchhee                : constant Unicode_Char := 16#AB24#;
   Ethiopic_Syllable_Cchhe                 : constant Unicode_Char := 16#AB25#;
   Ethiopic_Syllable_Cchho                 : constant Unicode_Char := 16#AB26#;
   Ethiopic_Syllable_Bba                   : constant Unicode_Char := 16#AB28#;
   Ethiopic_Syllable_Bbu                   : constant Unicode_Char := 16#AB29#;
   Ethiopic_Syllable_Bbi                   : constant Unicode_Char := 16#AB2A#;
   Ethiopic_Syllable_Bbaa                  : constant Unicode_Char := 16#AB2B#;
   Ethiopic_Syllable_Bbee                  : constant Unicode_Char := 16#AB2C#;
   Ethiopic_Syllable_Bbe                   : constant Unicode_Char := 16#AB2D#;
   Ethiopic_Syllable_Bbo                   : constant Unicode_Char := 16#AB2E#;
end Unicode.Names.Ethiopic_Extended_A;
