--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Cjk_Strokes is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Cjk_Stroke_T                            : constant Unicode_Char := 16#31C0#;
   Cjk_Stroke_Wg                           : constant Unicode_Char := 16#31C1#;
   Cjk_Stroke_Xg                           : constant Unicode_Char := 16#31C2#;
   Cjk_Stroke_Bxg                          : constant Unicode_Char := 16#31C3#;
   Cjk_Stroke_Sw                           : constant Unicode_Char := 16#31C4#;
   Cjk_Stroke_Hzz                          : constant Unicode_Char := 16#31C5#;
   Cjk_Stroke_Hzg                          : constant Unicode_Char := 16#31C6#;
   Cjk_Stroke_Hp                           : constant Unicode_Char := 16#31C7#;
   Cjk_Stroke_Hzwg                         : constant Unicode_Char := 16#31C8#;
   Cjk_Stroke_Szwg                         : constant Unicode_Char := 16#31C9#;
   Cjk_Stroke_Hzt                          : constant Unicode_Char := 16#31CA#;
   Cjk_Stroke_Hzzp                         : constant Unicode_Char := 16#31CB#;
   Cjk_Stroke_Hpwg                         : constant Unicode_Char := 16#31CC#;
   Cjk_Stroke_Hzw                          : constant Unicode_Char := 16#31CD#;
   Cjk_Stroke_Hzzz                         : constant Unicode_Char := 16#31CE#;
   Cjk_Stroke_N                            : constant Unicode_Char := 16#31CF#;
   Cjk_Stroke_H                            : constant Unicode_Char := 16#31D0#;
   Cjk_Stroke_S                            : constant Unicode_Char := 16#31D1#;
   Cjk_Stroke_P                            : constant Unicode_Char := 16#31D2#;
   Cjk_Stroke_Sp                           : constant Unicode_Char := 16#31D3#;
   Cjk_Stroke_D                            : constant Unicode_Char := 16#31D4#;
   Cjk_Stroke_Hz                           : constant Unicode_Char := 16#31D5#;
   Cjk_Stroke_Hg                           : constant Unicode_Char := 16#31D6#;
   Cjk_Stroke_Sz                           : constant Unicode_Char := 16#31D7#;
   Cjk_Stroke_Swz                          : constant Unicode_Char := 16#31D8#;
   Cjk_Stroke_St                           : constant Unicode_Char := 16#31D9#;
   Cjk_Stroke_Sg                           : constant Unicode_Char := 16#31DA#;
   Cjk_Stroke_Pd                           : constant Unicode_Char := 16#31DB#;
   Cjk_Stroke_Pz                           : constant Unicode_Char := 16#31DC#;
   Cjk_Stroke_Tn                           : constant Unicode_Char := 16#31DD#;
   Cjk_Stroke_Szz                          : constant Unicode_Char := 16#31DE#;
   Cjk_Stroke_Swg                          : constant Unicode_Char := 16#31DF#;
   Cjk_Stroke_Hxwg                         : constant Unicode_Char := 16#31E0#;
   Cjk_Stroke_Hzzzg                        : constant Unicode_Char := 16#31E1#;
   Cjk_Stroke_Pg                           : constant Unicode_Char := 16#31E2#;
   Cjk_Stroke_Q                            : constant Unicode_Char := 16#31E3#;
end Unicode.Names.Cjk_Strokes;
