--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Imperial_Aramaic is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Imperial_Aramaic_Letter_Aleph           :
      constant Unicode_Char := 16#10840#;
   Imperial_Aramaic_Letter_Beth            :
      constant Unicode_Char := 16#10841#;
   Imperial_Aramaic_Letter_Gimel           :
      constant Unicode_Char := 16#10842#;
   Imperial_Aramaic_Letter_Daleth          :
      constant Unicode_Char := 16#10843#;
   Imperial_Aramaic_Letter_He              :
      constant Unicode_Char := 16#10844#;
   Imperial_Aramaic_Letter_Waw             :
      constant Unicode_Char := 16#10845#;
   Imperial_Aramaic_Letter_Zayin           :
      constant Unicode_Char := 16#10846#;
   Imperial_Aramaic_Letter_Heth            :
      constant Unicode_Char := 16#10847#;
   Imperial_Aramaic_Letter_Teth            :
      constant Unicode_Char := 16#10848#;
   Imperial_Aramaic_Letter_Yodh            :
      constant Unicode_Char := 16#10849#;
   Imperial_Aramaic_Letter_Kaph            :
      constant Unicode_Char := 16#1084A#;
   Imperial_Aramaic_Letter_Lamedh          :
      constant Unicode_Char := 16#1084B#;
   Imperial_Aramaic_Letter_Mem             :
      constant Unicode_Char := 16#1084C#;
   Imperial_Aramaic_Letter_Nun             :
      constant Unicode_Char := 16#1084D#;
   Imperial_Aramaic_Letter_Samekh          :
      constant Unicode_Char := 16#1084E#;
   Imperial_Aramaic_Letter_Ayin            :
      constant Unicode_Char := 16#1084F#;
   Imperial_Aramaic_Letter_Pe              :
      constant Unicode_Char := 16#10850#;
   Imperial_Aramaic_Letter_Sadhe           :
      constant Unicode_Char := 16#10851#;
   Imperial_Aramaic_Letter_Qoph            :
      constant Unicode_Char := 16#10852#;
   Imperial_Aramaic_Letter_Resh            :
      constant Unicode_Char := 16#10853#;
   Imperial_Aramaic_Letter_Shin            :
      constant Unicode_Char := 16#10854#;
   Imperial_Aramaic_Letter_Taw             :
      constant Unicode_Char := 16#10855#;
   Imperial_Aramaic_Section_Sign           :
      constant Unicode_Char := 16#10857#;
   Imperial_Aramaic_Number_One             :
      constant Unicode_Char := 16#10858#;
   Imperial_Aramaic_Number_Two             :
      constant Unicode_Char := 16#10859#;
   Imperial_Aramaic_Number_Three           :
      constant Unicode_Char := 16#1085A#;
   Imperial_Aramaic_Number_Ten             :
      constant Unicode_Char := 16#1085B#;
   Imperial_Aramaic_Number_Twenty          :
      constant Unicode_Char := 16#1085C#;
   Imperial_Aramaic_Number_One_Hundred     :
      constant Unicode_Char := 16#1085D#;
   Imperial_Aramaic_Number_One_Thousand    :
      constant Unicode_Char := 16#1085E#;
   Imperial_Aramaic_Number_Ten_Thousand    :
      constant Unicode_Char := 16#1085F#;
end Unicode.Names.Imperial_Aramaic;
