--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Syloti_Nagri is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Syloti_Nagri_Letter_A                   : constant Unicode_Char := 16#A800#;
   Syloti_Nagri_Letter_I                   : constant Unicode_Char := 16#A801#;
   Syloti_Nagri_Sign_Dvisvara              : constant Unicode_Char := 16#A802#;
   Syloti_Nagri_Letter_U                   : constant Unicode_Char := 16#A803#;
   Syloti_Nagri_Letter_E                   : constant Unicode_Char := 16#A804#;
   Syloti_Nagri_Letter_O                   : constant Unicode_Char := 16#A805#;
   Syloti_Nagri_Sign_Hasanta               : constant Unicode_Char := 16#A806#;
   Syloti_Nagri_Letter_Ko                  : constant Unicode_Char := 16#A807#;
   Syloti_Nagri_Letter_Kho                 : constant Unicode_Char := 16#A808#;
   Syloti_Nagri_Letter_Go                  : constant Unicode_Char := 16#A809#;
   Syloti_Nagri_Letter_Gho                 : constant Unicode_Char := 16#A80A#;
   Syloti_Nagri_Sign_Anusvara              : constant Unicode_Char := 16#A80B#;
   Syloti_Nagri_Letter_Co                  : constant Unicode_Char := 16#A80C#;
   Syloti_Nagri_Letter_Cho                 : constant Unicode_Char := 16#A80D#;
   Syloti_Nagri_Letter_Jo                  : constant Unicode_Char := 16#A80E#;
   Syloti_Nagri_Letter_Jho                 : constant Unicode_Char := 16#A80F#;
   Syloti_Nagri_Letter_Tto                 : constant Unicode_Char := 16#A810#;
   Syloti_Nagri_Letter_Ttho                : constant Unicode_Char := 16#A811#;
   Syloti_Nagri_Letter_Ddo                 : constant Unicode_Char := 16#A812#;
   Syloti_Nagri_Letter_Ddho                : constant Unicode_Char := 16#A813#;
   Syloti_Nagri_Letter_To                  : constant Unicode_Char := 16#A814#;
   Syloti_Nagri_Letter_Tho                 : constant Unicode_Char := 16#A815#;
   Syloti_Nagri_Letter_Do                  : constant Unicode_Char := 16#A816#;
   Syloti_Nagri_Letter_Dho                 : constant Unicode_Char := 16#A817#;
   Syloti_Nagri_Letter_No                  : constant Unicode_Char := 16#A818#;
   Syloti_Nagri_Letter_Po                  : constant Unicode_Char := 16#A819#;
   Syloti_Nagri_Letter_Pho                 : constant Unicode_Char := 16#A81A#;
   Syloti_Nagri_Letter_Bo                  : constant Unicode_Char := 16#A81B#;
   Syloti_Nagri_Letter_Bho                 : constant Unicode_Char := 16#A81C#;
   Syloti_Nagri_Letter_Mo                  : constant Unicode_Char := 16#A81D#;
   Syloti_Nagri_Letter_Ro                  : constant Unicode_Char := 16#A81E#;
   Syloti_Nagri_Letter_Lo                  : constant Unicode_Char := 16#A81F#;
   Syloti_Nagri_Letter_Rro                 : constant Unicode_Char := 16#A820#;
   Syloti_Nagri_Letter_So                  : constant Unicode_Char := 16#A821#;
   Syloti_Nagri_Letter_Ho                  : constant Unicode_Char := 16#A822#;
   Syloti_Nagri_Vowel_Sign_A               : constant Unicode_Char := 16#A823#;
   Syloti_Nagri_Vowel_Sign_I               : constant Unicode_Char := 16#A824#;
   Syloti_Nagri_Vowel_Sign_U               : constant Unicode_Char := 16#A825#;
   Syloti_Nagri_Vowel_Sign_E               : constant Unicode_Char := 16#A826#;
   Syloti_Nagri_Vowel_Sign_Oo              : constant Unicode_Char := 16#A827#;
   Syloti_Nagri_Poetry_Mark_1              : constant Unicode_Char := 16#A828#;
   Syloti_Nagri_Poetry_Mark_2              : constant Unicode_Char := 16#A829#;
   Syloti_Nagri_Poetry_Mark_3              : constant Unicode_Char := 16#A82A#;
   Syloti_Nagri_Poetry_Mark_4              : constant Unicode_Char := 16#A82B#;
end Unicode.Names.Syloti_Nagri;
