--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Osmanya is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Osmanya_Letter_Alef                     :
      constant Unicode_Char := 16#10480#;
   Osmanya_Letter_Ba                       :
      constant Unicode_Char := 16#10481#;
   Osmanya_Letter_Ta                       :
      constant Unicode_Char := 16#10482#;
   Osmanya_Letter_Ja                       :
      constant Unicode_Char := 16#10483#;
   Osmanya_Letter_Xa                       :
      constant Unicode_Char := 16#10484#;
   Osmanya_Letter_Kha                      :
      constant Unicode_Char := 16#10485#;
   Osmanya_Letter_Deel                     :
      constant Unicode_Char := 16#10486#;
   Osmanya_Letter_Ra                       :
      constant Unicode_Char := 16#10487#;
   Osmanya_Letter_Sa                       :
      constant Unicode_Char := 16#10488#;
   Osmanya_Letter_Shiin                    :
      constant Unicode_Char := 16#10489#;
   Osmanya_Letter_Dha                      :
      constant Unicode_Char := 16#1048A#;
   Osmanya_Letter_Cayn                     :
      constant Unicode_Char := 16#1048B#;
   Osmanya_Letter_Ga                       :
      constant Unicode_Char := 16#1048C#;
   Osmanya_Letter_Fa                       :
      constant Unicode_Char := 16#1048D#;
   Osmanya_Letter_Qaaf                     :
      constant Unicode_Char := 16#1048E#;
   Osmanya_Letter_Kaaf                     :
      constant Unicode_Char := 16#1048F#;
   Osmanya_Letter_Laan                     :
      constant Unicode_Char := 16#10490#;
   Osmanya_Letter_Miin                     :
      constant Unicode_Char := 16#10491#;
   Osmanya_Letter_Nuun                     :
      constant Unicode_Char := 16#10492#;
   Osmanya_Letter_Waw                      :
      constant Unicode_Char := 16#10493#;
   Osmanya_Letter_Ha                       :
      constant Unicode_Char := 16#10494#;
   Osmanya_Letter_Ya                       :
      constant Unicode_Char := 16#10495#;
   Osmanya_Letter_A                        :
      constant Unicode_Char := 16#10496#;
   Osmanya_Letter_E                        :
      constant Unicode_Char := 16#10497#;
   Osmanya_Letter_I                        :
      constant Unicode_Char := 16#10498#;
   Osmanya_Letter_O                        :
      constant Unicode_Char := 16#10499#;
   Osmanya_Letter_U                        :
      constant Unicode_Char := 16#1049A#;
   Osmanya_Letter_Aa                       :
      constant Unicode_Char := 16#1049B#;
   Osmanya_Letter_Ee                       :
      constant Unicode_Char := 16#1049C#;
   Osmanya_Letter_Oo                       :
      constant Unicode_Char := 16#1049D#;
   Osmanya_Digit_Zero                      :
      constant Unicode_Char := 16#104A0#;
   Osmanya_Digit_One                       :
      constant Unicode_Char := 16#104A1#;
   Osmanya_Digit_Two                       :
      constant Unicode_Char := 16#104A2#;
   Osmanya_Digit_Three                     :
      constant Unicode_Char := 16#104A3#;
   Osmanya_Digit_Four                      :
      constant Unicode_Char := 16#104A4#;
   Osmanya_Digit_Five                      :
      constant Unicode_Char := 16#104A5#;
   Osmanya_Digit_Six                       :
      constant Unicode_Char := 16#104A6#;
   Osmanya_Digit_Seven                     :
      constant Unicode_Char := 16#104A7#;
   Osmanya_Digit_Eight                     :
      constant Unicode_Char := 16#104A8#;
   Osmanya_Digit_Nine                      :
      constant Unicode_Char := 16#104A9#;
end Unicode.Names.Osmanya;
