--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Batak is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Batak_Letter_A                          : constant Unicode_Char := 16#1BC0#;
   Batak_Letter_Simalungun_A               : constant Unicode_Char := 16#1BC1#;
   Batak_Letter_Ha                         : constant Unicode_Char := 16#1BC2#;
   Batak_Letter_Simalungun_Ha              : constant Unicode_Char := 16#1BC3#;
   Batak_Letter_Mandailing_Ha              : constant Unicode_Char := 16#1BC4#;
   Batak_Letter_Ba                         : constant Unicode_Char := 16#1BC5#;
   Batak_Letter_Karo_Ba                    : constant Unicode_Char := 16#1BC6#;
   Batak_Letter_Pa                         : constant Unicode_Char := 16#1BC7#;
   Batak_Letter_Simalungun_Pa              : constant Unicode_Char := 16#1BC8#;
   Batak_Letter_Na                         : constant Unicode_Char := 16#1BC9#;
   Batak_Letter_Mandailing_Na              : constant Unicode_Char := 16#1BCA#;
   Batak_Letter_Wa                         : constant Unicode_Char := 16#1BCB#;
   Batak_Letter_Simalungun_Wa              : constant Unicode_Char := 16#1BCC#;
   Batak_Letter_Pakpak_Wa                  : constant Unicode_Char := 16#1BCD#;
   Batak_Letter_Ga                         : constant Unicode_Char := 16#1BCE#;
   Batak_Letter_Simalungun_Ga              : constant Unicode_Char := 16#1BCF#;
   Batak_Letter_Ja                         : constant Unicode_Char := 16#1BD0#;
   Batak_Letter_Da                         : constant Unicode_Char := 16#1BD1#;
   Batak_Letter_Ra                         : constant Unicode_Char := 16#1BD2#;
   Batak_Letter_Simalungun_Ra              : constant Unicode_Char := 16#1BD3#;
   Batak_Letter_Ma                         : constant Unicode_Char := 16#1BD4#;
   Batak_Letter_Simalungun_Ma              : constant Unicode_Char := 16#1BD5#;
   Batak_Letter_Southern_Ta                : constant Unicode_Char := 16#1BD6#;
   Batak_Letter_Northern_Ta                : constant Unicode_Char := 16#1BD7#;
   Batak_Letter_Sa                         : constant Unicode_Char := 16#1BD8#;
   Batak_Letter_Simalungun_Sa              : constant Unicode_Char := 16#1BD9#;
   Batak_Letter_Mandailing_Sa              : constant Unicode_Char := 16#1BDA#;
   Batak_Letter_Ya                         : constant Unicode_Char := 16#1BDB#;
   Batak_Letter_Simalungun_Ya              : constant Unicode_Char := 16#1BDC#;
   Batak_Letter_Nga                        : constant Unicode_Char := 16#1BDD#;
   Batak_Letter_La                         : constant Unicode_Char := 16#1BDE#;
   Batak_Letter_Simalungun_La              : constant Unicode_Char := 16#1BDF#;
   Batak_Letter_Nya                        : constant Unicode_Char := 16#1BE0#;
   Batak_Letter_Ca                         : constant Unicode_Char := 16#1BE1#;
   Batak_Letter_Nda                        : constant Unicode_Char := 16#1BE2#;
   Batak_Letter_Mba                        : constant Unicode_Char := 16#1BE3#;
   Batak_Letter_I                          : constant Unicode_Char := 16#1BE4#;
   Batak_Letter_U                          : constant Unicode_Char := 16#1BE5#;
   Batak_Sign_Tompi                        : constant Unicode_Char := 16#1BE6#;
   Batak_Vowel_Sign_E                      : constant Unicode_Char := 16#1BE7#;
   Batak_Vowel_Sign_Pakpak_E               : constant Unicode_Char := 16#1BE8#;
   Batak_Vowel_Sign_Ee                     : constant Unicode_Char := 16#1BE9#;
   Batak_Vowel_Sign_I                      : constant Unicode_Char := 16#1BEA#;
   Batak_Vowel_Sign_Karo_I                 : constant Unicode_Char := 16#1BEB#;
   Batak_Vowel_Sign_O                      : constant Unicode_Char := 16#1BEC#;
   Batak_Vowel_Sign_Karo_O                 : constant Unicode_Char := 16#1BED#;
   Batak_Vowel_Sign_U                      : constant Unicode_Char := 16#1BEE#;
   Batak_Vowel_Sign_U_For_Simalungun_Sa    : constant Unicode_Char := 16#1BEF#;
   Batak_Consonant_Sign_Ng                 : constant Unicode_Char := 16#1BF0#;
   Batak_Consonant_Sign_H                  : constant Unicode_Char := 16#1BF1#;
   Batak_Pangolat                          : constant Unicode_Char := 16#1BF2#;
   Batak_Panongonan                        : constant Unicode_Char := 16#1BF3#;
   Batak_Symbol_Bindu_Na_Metek             : constant Unicode_Char := 16#1BFC#;
   Batak_Symbol_Bindu_Pinarboras           : constant Unicode_Char := 16#1BFD#;
   Batak_Symbol_Bindu_Judul                : constant Unicode_Char := 16#1BFE#;
   Batak_Symbol_Bindu_Pangolat             : constant Unicode_Char := 16#1BFF#;
end Unicode.Names.Batak;
