--  This file is built automatically from data found on the
--  unicode web site (http://www.unicode.org)
--  in version 8.0.0 and thus is a subject to unicode license:
--
--  UNICODE, INC. LICENSE AGREEMENT - DATA FILES AND SOFTWARE
--  See Terms of Use for definitions of Unicode Inc.'s
--  Data Files and Software.
--
--  NOTICE TO USER: Carefully read the following legal agreement.
--  BY DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING UNICODE INC.'S
--  DATA FILES ("DATA FILES"), AND/OR SOFTWARE ("SOFTWARE"),
--  YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
--  TERMS AND CONDITIONS OF THIS AGREEMENT.
--  IF YOU DO NOT AGREE, DO NOT DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE
--  THE DATA FILES OR SOFTWARE.
--
--  COPYRIGHT AND PERMISSION NOTICE
--
--  Copyright © 1991-2021 Unicode, Inc. All rights reserved.
--  Distributed under the Terms of Use
--  in https://www.unicode.org/copyright.html.
--
--  Permission is hereby granted, free of charge, to any person obtaining
--  a copy of the Unicode data files and any associated documentation
--  (the "Data Files") or Unicode software and any associated documentation
--  (the "Software") to deal in the Data Files or Software
--  without restriction, including without limitation the rights to use,
--  copy, modify, merge, publish, distribute, and/or sell copies of
--  the Data Files or Software, and to permit persons to whom the Data Files
--  or Software are furnished to do so, provided that either
--  (a) this copyright and permission notice appear with all copies
--  of the Data Files or Software, or
--  (b) this copyright and permission notice appear in associated
--  Documentation.
--
--  THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
--  ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
--  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
--  NONINFRINGEMENT OF THIRD PARTY RIGHTS.
--  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
--  NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
--  DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
--  DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
--  TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
--  PERFORMANCE OF THE DATA FILES OR SOFTWARE.
--
--  Except as contained in this notice, the name of a copyright holder
--  shall not be used in advertising or otherwise to promote the sale,
--  use or other dealings in these Data Files or Software without prior
--  written authorization of the copyright holder.
package Unicode.Names.Phoenician is
   pragma Preelaborate;
   pragma Style_Checks (Off);

   Phoenician_Letter_Alf                   :
      constant Unicode_Char := 16#10900#;
   Phoenician_Letter_Bet                   :
      constant Unicode_Char := 16#10901#;
   Phoenician_Letter_Gaml                  :
      constant Unicode_Char := 16#10902#;
   Phoenician_Letter_Delt                  :
      constant Unicode_Char := 16#10903#;
   Phoenician_Letter_He                    :
      constant Unicode_Char := 16#10904#;
   Phoenician_Letter_Wau                   :
      constant Unicode_Char := 16#10905#;
   Phoenician_Letter_Zai                   :
      constant Unicode_Char := 16#10906#;
   Phoenician_Letter_Het                   :
      constant Unicode_Char := 16#10907#;
   Phoenician_Letter_Tet                   :
      constant Unicode_Char := 16#10908#;
   Phoenician_Letter_Yod                   :
      constant Unicode_Char := 16#10909#;
   Phoenician_Letter_Kaf                   :
      constant Unicode_Char := 16#1090A#;
   Phoenician_Letter_Lamd                  :
      constant Unicode_Char := 16#1090B#;
   Phoenician_Letter_Mem                   :
      constant Unicode_Char := 16#1090C#;
   Phoenician_Letter_Nun                   :
      constant Unicode_Char := 16#1090D#;
   Phoenician_Letter_Semk                  :
      constant Unicode_Char := 16#1090E#;
   Phoenician_Letter_Ain                   :
      constant Unicode_Char := 16#1090F#;
   Phoenician_Letter_Pe                    :
      constant Unicode_Char := 16#10910#;
   Phoenician_Letter_Sade                  :
      constant Unicode_Char := 16#10911#;
   Phoenician_Letter_Qof                   :
      constant Unicode_Char := 16#10912#;
   Phoenician_Letter_Rosh                  :
      constant Unicode_Char := 16#10913#;
   Phoenician_Letter_Shin                  :
      constant Unicode_Char := 16#10914#;
   Phoenician_Letter_Tau                   :
      constant Unicode_Char := 16#10915#;
   Phoenician_Number_One                   :
      constant Unicode_Char := 16#10916#;
   Phoenician_Number_Ten                   :
      constant Unicode_Char := 16#10917#;
   Phoenician_Number_Twenty                :
      constant Unicode_Char := 16#10918#;
   Phoenician_Number_One_Hundred           :
      constant Unicode_Char := 16#10919#;
   Phoenician_Number_Two                   :
      constant Unicode_Char := 16#1091A#;
   Phoenician_Number_Three                 :
      constant Unicode_Char := 16#1091B#;
   Phoenician_Word_Separator               :
      constant Unicode_Char := 16#1091F#;
end Unicode.Names.Phoenician;
